local shadercode = [[
uniform vec2 size;
uniform float i;

vec4 effect ( vec4 color, Image texture, vec2 uv, vec2 xy )
{
	xy = floor ( ( xy + vec2 ( i ) ) / size );

	if ( mod ( xy.x + xy.y, 2.0 ) < 1.0 )
		return vec4 ( 1.0, 1.0, 1.0, 1.0 );
	else
		return vec4 ( 0.6, 0.6, 0.6, 1.0 );
}
]]
local shader

local COLOR = {
    GRAY = {155,155,155},
    WHITE = {255,255,255}
}

local checkerboard = function(x,y,width,height,boxwidth,boxheight,ox,oy)
    local ox,oy = ox or 0,oy or 0
    local start = x - ox 
    local starty = y - oy
    local no = 0
    for y=starty,starty + height + oy,boxheight do 
        local offset = no % 2 == 1
        local xno = 0
        for x=start,start + width + ox,boxwidth do
            local color = COLOR.GRAY 
            if offset then 
                if xno % 2 == 1 then 
                    color = COLOR.WHITE
                end
            else 
                if xno % 2 == 0 then 
                    color = COLOR.WHITE
                end 
            end
            love.graphics.setColor(color)
            love.graphics.rectangle("fill",x,y,boxwidth,boxheight)
            xno = xno + 1
        end
        no = no + 1 
    end 
end

function love.load ( )
	shader = love.graphics.newShader ( shadercode )
end

local i = 0
local mode = "func"

function love.update ( dt )
	i = i + dt * 10;
	shader:send ( "i", i )
end

function love.keypressed ( )
	if mode == "func" then mode = "shader" else mode = "func" end
end

function love.draw()
	
	local t = love.timer.getTime ( )
	for _ = 1, 25 do
		if mode == "func" then
			checkerboard(0,0,800,600,10,10,i,i)
		else
			shader:send ( "size", { 10, 10 } )
			love.graphics.setShader ( shader )
			love.graphics.rectangle ( "fill", 0, 0, 800, 600 )
			love.graphics.setShader ( )
		end
	end
	t = love.timer.getTime ( ) - t
	love.graphics.setColor ( 0, 0, 0 )
	love.graphics.print ( "press space to toggle mode", 10, 30 )
	love.graphics.print ( t, 10, 10 )
end